@@ -4,7 +4,7 @@
 modname = 'rqlcontroller'
 distname = 'cubicweb-rqlcontroller'
 
-numversion = (0, 7, 1)
+numversion = (0, 7, 2)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -14,7 +14,7 @@ description = 'restfull rql edition capabilities'
 web = 'http://www.cubicweb.org/project/%s' % distname
 
 __depends__ = {
-    'cubicweb': '>= 3.27.3',
+    'cubicweb': '>= 3.27.3, < 3.32',
     'six': None,
 }
 __recommends__ = {'cubicweb-signedrequest': None}
